@@ -469,6 +469,25 @@ def test_roundtrip_test(fourc_file, tmp_path):
         )
 
 
+@pytest.mark.skipif(CONFIG.name != "4C_docker_main", reason="Not using docker config.")
+@pytest.mark.parametrize(
+    "fourc_file",
+    [
+        str(f.resolve())
+        for f in pathlib.Path("/home/user/4C/tests/input_files").glob("*.4C.yaml")
+    ],
+)
+def test_readin_all_test_files(fourc_file):
+    """Read all known 4C files and check if valid."""
+    fourc_file = pathlib.Path(fourc_file)
+
+    # Load 4C input test file
+    fourc_input = FourCInput.from_4C_yaml(fourc_file)
+
+    # Check if it is valid
+    fourc_input.validate()
+
+
 def test_extract_header_sections(fourc_input, fourc_input_with_legacy_section):
     """Test the header extraction."""
 
@@ -566,24 +585,25 @@ def test_sort_by_section_names():
     ]
 
     # also use end subset to also add some lowercase sections
-    typed_and_functions = (
-        typed_sections[:15]
-        + typed_sections[-15:]
-        + [f"FUNCT{i}" for i in [1, 2, 9, 10, 33]]
-    )
+    typed_sections = typed_sections[:15] + typed_sections[-15:]
+    typed_sections = sorted(typed_sections, key=str.lower)
 
-    # sort with proper key: alphabetically for typed, numerically for FUNCT
-    typed_and_functions = sorted(
-        typed_and_functions,
-        key=lambda s: (
-            s.lower() if not s.startswith("FUNCT") else f"funct{s[5:].zfill(10)}"
-        ),
-    )
+    # use first 5 'DESIGN * ' sections
+    design_sections = [
+        s for s in CONFIG.sections.typed_sections if s.startswith("DESIGN")
+    ][:5]
+    design_sections = sorted(design_sections, key=str.lower)
+
+    # create some FUNCT sections
+    function_sections = [f"FUNCT{i}" for i in [1, 2, 9, 10, 33]]
 
     correct_section_order = (
         [CONFIG.fourc_metadata["metadata"]["description_section_name"]]
         + CONFIG.fourc_json_schema["required"]
-        + typed_and_functions
+        + typed_sections
+        + ["MATERIALS"]
+        + design_sections
+        + function_sections
         + CONFIG.sections.legacy_sections
     )
 
